@@ -1,6 +1,5 @@
 #! /usr/bin/env python -tt
 # vim: set fileencoding=utf-8
-from __future__ import unicode_literals
 """
 Hierarchical Yaml Python Config
 ===============================
@@ -10,7 +9,7 @@ A simple python lib allowing hierarchical config files in YAML syntax.
 License
 -------
 
-(c) 2014 - 2020 Klaus Zerwes zero-sys.net
+(c) 2014 - 2022 Klaus Zerwes zero-sys.net
 This package is free software.
 This software is licensed under the terms of the
 GNU GENERAL PUBLIC LICENSE version 3 or later,
@@ -18,15 +17,16 @@ as published by the Free Software Foundation.
 See https://www.gnu.org/licenses/gpl.html
 """
 
+from __future__ import unicode_literals
 
 import sys
 import os
-import yaml
-from yaml import parser
 import logging
 from distutils.util import strtobool
 import re
 import io
+import yaml
+from yaml import parser
 from jinja2 import Environment, Undefined, DebugUndefined, StrictUndefined, TemplateError
 
 from . import odyldo
@@ -44,7 +44,7 @@ __version__ = version.VERSION
 
 logger = logging.getLogger(__name__)
 
-_usedefaultyamlloader = False
+_USEDEFAULTYAMLLOADER = False
 
 class HiYaPyCoInvocationException(Exception):
     """dummy Exception raised on wrong invocation"""
@@ -71,14 +71,17 @@ METHOD_MERGE = METHODS['METHOD_MERGE']
 METHOD_SUBSTITUTE = METHODS['METHOD_SUBSTITUTE']
 
 
-class HiYaPyCo():
+class HiYaPyCo:
     """Main class"""
+    # pylint: disable=too-many-instance-attributes disable=too-many-branches disable=too-many-statements
     def __init__(self, *args, **kwargs):
         """
         args: YAMLfile(s)
         kwargs:
-          * method: one of hiyapyco.METHOD_SIMPLE | hiyapyco.METHOD_MERGE | hiyapyco.METHOD_SUBSTITUTE
-          * mergelists: boolean (default: True) try to merge lists (only makes sense if hiyapyco.METHOD_MERGE or hiyapyco.METHOD_SUBSTITUTE)
+          * method: one of
+            hiyapyco.METHOD_SIMPLE | hiyapyco.METHOD_MERGE | hiyapyco.METHOD_SUBSTITUTE
+          * mergelists: boolean (default: True) try to merge lists
+            (only makes sense if hiyapyco.METHOD_MERGE or hiyapyco.METHOD_SUBSTITUTE)
           * interpolate: boolean (default: False)
           * castinterpolated: boolean (default: False) try to cast values after interpolating
           * usedefaultyamlloader: boolean (default: False)
@@ -88,7 +91,8 @@ class HiYaPyCo():
           * loglevelmissingfiles
 
         Returns a representation of the merged and (if requested) interpolated config.
-        Will mostly be a OrderedDict (dict if usedefaultyamlloader), but can be of any other type, depending on the yaml files.
+        Will mostly be a OrderedDict (dict if usedefaultyamlloader), but can be of any other type,
+        depending on the yaml files.
         """
         self._data = None
         self._files = []
@@ -103,7 +107,7 @@ class HiYaPyCo():
                     )
             self.method = kwargs['method']
             del kwargs['method']
-        if self.method == None:
+        if self.method is None:
             self.method = METHOD_SIMPLE
 
         self.mergelists = True
@@ -141,8 +145,8 @@ class HiYaPyCo():
                         'value of "usedefaultyamlloader" must be boolean (got: "%s" as %s)' %
                         (kwargs['usedefaultyamlloader'], type(kwargs['usedefaultyamlloader']),)
                         )
-            global _usedefaultyamlloader
-            _usedefaultyamlloader = kwargs['usedefaultyamlloader']
+            global _USEDEFAULTYAMLLOADER
+            _USEDEFAULTYAMLLOADER = kwargs['usedefaultyamlloader']
             del kwargs['usedefaultyamlloader']
 
         self.failonmissingfiles = True
@@ -188,7 +192,7 @@ class HiYaPyCo():
                 if '\n' in yamlfile:
                     logger.debug('loading yaml doc from str ...')
                     f = yamlfile
-                    self._load_data(_usedefaultyamlloader, yamlfile)
+                    self._load_data(_USEDEFAULTYAMLLOADER, yamlfile)
                 else:
                     fn = yamlfile
                     if not os.path.isabs(yamlfile):
@@ -197,7 +201,7 @@ class HiYaPyCo():
                     try:
                         with io.open(fn, 'r', encoding=self.encoding) as f:
                             logger.debug('open4reading: file %s' % f)
-                            self._load_data(_usedefaultyamlloader, f)
+                            self._load_data(_USEDEFAULTYAMLLOADER, f)
                     except IOError as e:
                         logger.log(self.loglevelonmissingfiles, e)
                         if not fn == yamlfile:
@@ -227,8 +231,8 @@ class HiYaPyCo():
         if self.interpolate:
             self._data = self._interpolate(self._data)
 
-    def _load_data(self, _usedefaultyamlloader, f):
-        if _usedefaultyamlloader:
+    def _load_data(self, _USEDEFAULTYAMLLOADER, f):
+        if _USEDEFAULTYAMLLOADER:
             ydata_generator = yaml.safe_load_all(f)
         else:
             ydata_generator = odyldo.safe_load_all(f)
@@ -251,14 +255,16 @@ class HiYaPyCo():
     def _updatefiles(self, arg):
         if isinstance(arg, strTypes):
             if arg in self._files:
-                logger.warn('ignoring duplicated file %s' % arg)
+                logger.warning('ignoring duplicated file %s' % arg)
                 return
             self._files.append(arg)
         elif isinstance(arg, listTypes):
             for larg in arg:
                 self._updatefiles(larg)
         else:
-            raise HiYaPyCoInvocationException('unable to handle arg %s of type %s' % (arg, type(arg),))
+            raise HiYaPyCoInvocationException(
+                'unable to handle arg %s of type %s' % (arg, type(arg),)
+                )
 
     def _interpolate(self, d):
         logger.debug('interpolate "%s" of type %s ...' % (d, type(d),))
@@ -314,6 +320,7 @@ class HiYaPyCo():
         elif isinstance(b, listTypes):
             logger.debug('simplemerge: listTypes a "%s"  w/ b "%s"' % (a, b,))
             if isinstance(a, listTypes):
+                # pylint: disable=unused-variable
                 for k, v in enumerate(b):
                     try:
                         a[k] = self._simplemerge(a[k], b[k])
@@ -356,7 +363,9 @@ class HiYaPyCo():
                 logger.debug('deepmerge: dict ... "%s" and "%s"' % (a, b,))
                 for k in b:
                     if k in a:
-                        logger.debug('deepmerge dict: loop for key "%s": "%s" and "%s"' % (k, a[k], b[k],))
+                        logger.debug(
+                            'deepmerge dict: loop for key "%s": "%s" and "%s"' % (k, a[k], b[k],)
+                            )
                         a[k] = self._deepmerge(a[k], b[k])
                     else:
                         logger.debug('deepmerge dict: set key %s' % k)
@@ -368,7 +377,8 @@ class HiYaPyCo():
                         a = self._deepmerge(a, bd)
                     else:
                         raise HiYaPyCoImplementationException(
-                            'can not merge element from list of type %s to dict (@ "%s" try to merge "%s")' %
+                            'can not merge element from list of type %s to dict '
+                            '(@ "%s" try to merge "%s")' %
                             (type(b), a, b,)
                         )
             else:
@@ -392,7 +402,10 @@ class HiYaPyCo():
             a = b
         elif isinstance(a, listTypes):
             if isinstance(b, listTypes):
-                logger.debug('deepmerge: lists extend %s:"%s" by %s:"%s"' % (type(a), a, type(b), b,))
+                logger.debug(
+                    'deepmerge: lists extend %s:"%s" by %s:"%s"' %
+                    (type(a), a, type(b), b,)
+                    )
                 a.extend(be for be in b if be not in a and
                             (isinstance(be, primitiveTypes) or isinstance(be, listTypes))
                         )
@@ -404,7 +417,7 @@ class HiYaPyCo():
                 for k, ad in enumerate(a):
                     logger.debug('deepmerge ad "%s" w/ k "%s" of type %s' % (ad, k, type(ad)))
                     if isinstance(ad, dict):
-                        if k in srcdicts.keys():
+                        if k in srcdicts:
                             # we merge only if at least one key in dict is matching
                             merge = False
                             if self.mergelists:
@@ -413,16 +426,19 @@ class HiYaPyCo():
                                         merge = True
                                         break
                             if merge:
+                                # pylint: disable=undefined-loop-variable
+                                # FIXME undefined-loop-variable : this is not well readable !!!
                                 logger.debug(
-                                        'deepmerge ad: deep merge list dict elem w/ key:%s: "%s" and "%s"'
-                                        % (ak, ad, srcdicts[k],)
+                                    'deepmerge ad: deep merge list dict elem w/ '
+                                    'key:%s: "%s" and "%s"' %
+                                    (ak, ad, srcdicts[k],)
                                     )
                                 a[k] = self._deepmerge(ad, srcdicts[k])
                                 del srcdicts[k]
                 logger.debug('deepmerge list: remaining srcdicts elems: %s' % srcdicts)
-                for k in srcdicts.keys():
-                    logger.debug('deepmerge list: new dict append %s:%s' % (k, srcdicts[k]))
-                    a.append(srcdicts[k])
+                for k, v in srcdicts.items():
+                    logger.debug('deepmerge list: new dict append %s:%s' % (k, v))
+                    a.append(v)
             else:
                 raise HiYaPyCoImplementationException(
                         'can not merge %s to %s (@ "%s"  try to merge "%s")' %
@@ -433,7 +449,10 @@ class HiYaPyCo():
                 logger.debug('deepmerge: dict ... "%s" and "%s"' % (a, b,))
                 for k in b:
                     if k in a:
-                        logger.debug('deepmerge dict: loop for key "%s": "%s" and "%s"' % (k, a[k], b[k],))
+                        logger.debug(
+                            'deepmerge dict: loop for key "%s": "%s" and "%s"' %
+                            (k, a[k], b[k],)
+                            )
                         a[k] = self._deepmerge(a[k], b[k])
                     else:
                         logger.debug('deepmerge dict: set key %s' % k)
@@ -445,9 +464,10 @@ class HiYaPyCo():
                         a = self._deepmerge(a, bd)
                     else:
                         raise HiYaPyCoImplementationException(
-                                'can not merge element from list of type %s to dict (@ "%s" try to merge "%s")' %
-                                (type(b), a, b,)
-                                )
+                            'can not merge element from list of type %s to dict '
+                            '(@ "%s" try to merge "%s")' %
+                            (type(b), a, b,)
+                            )
             else:
                 raise HiYaPyCoImplementationException(
                         'can not merge %s to %s (@ "%s" try to merge "%s")' %
@@ -458,6 +478,7 @@ class HiYaPyCo():
         return a
 
     def yamlfiles(self):
+        """returns the list of parsed yaml files / strings"""
         return self._files
 
     def __str__(self):
@@ -474,10 +495,9 @@ class HiYaPyCo():
 
 def dump(data, **kwds):
     """dump the data as YAML"""
-    if _usedefaultyamlloader:
+    if _USEDEFAULTYAMLLOADER:
         return yaml.safe_dump(data, **kwds)
-    else:
-        return odyldo.safe_dump(data, **kwds)
+    return odyldo.safe_dump(data, **kwds)
 
 def load(*args, **kwargs):
     """
@@ -487,7 +507,8 @@ def load(*args, **kwargs):
     args: YAMLfile(s)
     kwargs:
       * method: one of hiyapyco.METHOD_SIMPLE | hiyapyco.METHOD_MERGE | hiyapyco.METHOD_SUBSTITUTE
-      * mergelists: boolean (default: True) try to merge lists (only makes sense if hiyapyco.METHOD_MERGE or hiyapyco.METHOD_SUBSTITUTE)
+      * mergelists: boolean (default: True) try to merge lists
+        (only makes sense if hiyapyco.METHOD_MERGE or hiyapyco.METHOD_SUBSTITUTE)
       * interpolate: boolean (default: False)
       * castinterpolated: boolean (default: False) try to cast values after interpolating
       * usedefaultyamlloader: boolean (default: False)
@@ -497,10 +518,10 @@ def load(*args, **kwargs):
       * loglevelmissingfiles
 
     Returns a representation of the merged and (if requested) interpolated config.
-    Will mostly be a OrderedDict (dict if usedefaultyamlloader), but can be of any other type, depending on the yaml files.
+    Will mostly be a OrderedDict (dict if usedefaultyamlloader), but can be of any other type,
+    depending on the yaml files.
     """
     hiyapyco = HiYaPyCo(*args, **kwargs)
     return hiyapyco.data()
 
 # vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4 smartindent nu
-
