@@ -7,7 +7,7 @@ ODYLDo - Ordered Dict Yaml Loader / Dumper
 a simple implementation of a Ordered Dict Loader for PyYAML;
 because chaos is fun but order matters on loading dicts from a yaml file;
 
-(c) 2014 - 2020 Klaus Zerwes zero-sys.net
+(c) 2014 - 2022 Klaus Zerwes zero-sys.net
 This package is free software.
 This software is licensed under the terms of the
 GNU GENERAL PUBLIC LICENSE version 3 or later,
@@ -15,17 +15,11 @@ as published by the Free Software Foundation.
 See https://www.gnu.org/licenses/gpl.html
 """
 
-try:
-    from collections import OrderedDict
-except ImportError:
-    # try importing the backported replacement
-    # requires a: `pip-2.6 install ordereddict`
-    from ordereddict import OrderedDict 
-
 import yaml
 import yaml.loader
 import yaml.dumper
 import yaml.representer
+from collections import OrderedDict
 
 # @see: yaml.resolver.DEFAULT_MAPPING_TAG
 ODYLDoYAMLMAPS = [
